===============================
ahoy
===============================

.. image:: https://img.shields.io/travis/eddiejessup/ahoy.svg
        :target: https://travis-ci.org/eddiejessup/ahoy

.. image:: https://img.shields.io/pypi/v/ahoy.svg
        :target: https://pypi.python.org/pypi/ahoy


Agent-based simulations of active particles

* Free software: BSD license
* Documentation: https://ahoy.readthedocs.org.

Features
--------

* TODO
